| Title: | User Interface for visual programming of lasR pipelines |
|---|---|
| Description: | User Interface for visual programming of lasR pipeline. Drag and drop and connect stage to build pipelines interactively in a web app. |
| Authors: | Jean-Romain Roussel [aut, cre, cph] |
| Maintainer: | Jean-Romain Roussel <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-22 07:19:49 UTC |
| Source: | https://github.com/r-lidar-lab/lasRui |
Drag and drop and connect stages to build a pipeline using a web API
lasRui()lasRui()